# [Berry Dashboard](https://app-generator.dev/product/berry-dashboard/) Django Integration

Modern template for **Django** built with **[Berry Dashboard](https://app-generator.dev/product/berry-dashboard/)**, an open-source `Bootstrap` UI Kit released by [CodedThemes](https://app-generator.dev/agency/codedthemes/).

- [Django Admin Berry Dashboard](https://app-generator.dev/docs/products/django-libs/theme-berry.html) - Documentation & Support Links
- [Django Berry Dashboard Dashboard](https://app-generator.dev/product/berry-dashboard/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## **Features**

- [Berry Dashboard](https://app-generator.dev/product/berry-dashboard/) Design Integration
  - Dashboard page
  - Color, Typography, Icons 
  - Authentication: Login, Register
  
<br />

## [Berry Dashboard](https://app-generator.dev/product/berry-dashboard/) Starters

Pre-built starters for coding dashboards and services (APIs, DataTables) with speed.

### [Django Berry Dashboard](https://app-generator.dev/product/berry-dashboard/django/)

> The FREE Version (MIT License) - [Live Demo](https://django-berry.onrender.com).

- Simple, Easy-to-Extend Codebase
- [Berry Dashboard](https://app-generator.dev/product/berry-dashboard/) Integration 
- Bootstrap Styling 
- Dynamic Tables
- Dynamic API
- Charts
- **CLI for Coding Tasks**
  - `Commit/rollback Git Changes`
  - `Backup & restore DB`
  - `Interact with Django Core` via CLI
  - `Update Environment variables`
  - `Update Dependencies`
- Session-based Authentication, Password recovery
- DB Persistence: SQLite (default), can be used with MySql, PgSql
- Docker, CI/CD for Render
- [Integrate Vite](https://app-generator.dev/docs/technologies/vite/index.html) for assets management

![Django Berry - Modern template for Django Admin Section crafted on top of a modern Bootstrap, Open-Source Design.](https://user-images.githubusercontent.com/51070104/215728710-d1ee7fef-8153-402b-9741-371e1c01cd36.png)

<br />

## [Django Berry Dashboard PRO](https://app-generator.dev/product/berry-dashboard-pro/django/)

> The premium version provides more features, priority on support, and is more often updated - [Live Demo](https://django-berry-pro.onrender.com/dashboard/).

- Simple, Easy-to-Extend Codebase
- [Berry Dashboard](https://app-generator.dev/product/berry-dashboard/) PRO Design Integration 
- Bootstrap Styling 
- Dynamic Tables - read [docs](https://app-generator.dev/docs/developer-tools/dynamic-datatables.html)
- Dynamic API - read [docs](https://app-generator.dev/docs/developer-tools/dynamic-api.html)
- Charts
- Session-based Authentication, Password recovery
- OAuth (GitHub & Google)
- DB Persistence: SQLite (default), can be used with MySql, PgSql
- [Django CLI Package](https://app-generator.dev/docs/developer-tools/django-cli/index.html)
    - [Commit/rollback Git Changes](https://app-generator.dev/docs/developer-tools/django-cli/git-interface.html)
    - `Backup & restore DB`
    - [Interact with Django Core](https://app-generator.dev/docs/developer-tools/django-cli/query-django.html)
    - `Manage Environment`
    - `Manage Dependencies`
- Session-based Authentication, Password recovery
- DB Persistence: SQLite (default), can be used with MySql, PgSql
- Docker, CI/CD for Render
- [Integrate Vite](https://app-generator.dev/docs/technologies/vite/index.html) for assets management

![Berry Bootstrap 5 PRO - Premium Template Django Template integrated with Django.](https://user-images.githubusercontent.com/51070104/215728155-9b9cfe26-96e8-49c3-8a08-131d96f4f2eb.png)

<br />

## `Customize` with [Django App Generator](https://app-generator.dev/tools/django-generator/)

- Access the [App Generator](https://app-generator.dev/tools/django-generator/) page
- Select the preferred design
- (Optional) Design Database: edit models and fields
- (Optional) Edit the fields for the extended user model
- (Optional) Enable OAuth for GitHub
- (Optional) Add Celery (async tasks)
- (Optional) Enable Dynamic API Module
- Docker Scripts
- Render CI/Cd Scripts

**The generated Django project is available as a ZIP Archive and also uploaded to GitHub.**

![Django Generator - User Interface for choosing the Design](https://github.com/user-attachments/assets/b989c434-1c53-49ff-8dda-b46dbfc142ac) 

![Django App Generator - User Interface for Edit the Extended User Model](https://github.com/user-attachments/assets/f1a5fb68-a5ba-49c9-a3ae-91716de09912) 

<br />

---
**[Berry Dashboard](https://app-generator.dev/product/berry-dashboard/)** Django Integration - Library provided by **[App-Generator](https://app-generator.dev)**
